@@ -6,5 +6,7 @@ from .redis_manager import RedisManager
 from .server import Server
 from .namespace import Namespace
 
-__all__ = [Middleware, Server, BaseManager, PubSubManager, KombuManager,
-           RedisManager, Namespace]
+__version__ = '1.5.1'
+
+__all__ = [__version__, Middleware, Server, BaseManager, PubSubManager,
+           KombuManager, RedisManager, Namespace]
